@@ -119,6 +119,7 @@ operation_done (SeahorseOperation *operation, SeahorseWidget *swidget)
     }
     
     operation_progress (operation, "", 0.0, swidget);
+    g_object_set_data (G_OBJECT (swidget), "operation", NULL);
 }
 
 static void
@@ -146,9 +147,14 @@ seahorse_progress_status_set_operation (SeahorseWidget *swidget,
     
     prev = SEAHORSE_OPERATION (g_object_get_data (G_OBJECT (swidget), "operation"));
     if (prev) {
+	    
+        /* If it's the same operation, just ignore */
+        if (prev == operation)
+            return;
         
         /* If the previous one was a multi operation, just piggy back this one in */
         if (SEAHORSE_IS_MULTI_OPERATION (prev)) {
+       	    g_object_ref (operation);
             seahorse_multi_operation_take (SEAHORSE_MULTI_OPERATION (prev), operation);
             return;
         }
@@ -157,6 +163,7 @@ seahorse_progress_status_set_operation (SeahorseWidget *swidget,
         disconnect_progress (swidget, prev);
     }
         
+    g_object_ref (operation);
     g_object_set_data_full (G_OBJECT (swidget), "operation", operation, 
                             (GDestroyNotify)g_object_unref);
     g_signal_connect (swidget, "destroy", 
@@ -290,7 +297,7 @@ progress_show (SeahorseOperation *operation)
     /* Cancel events */
     glade_xml_signal_connect_data (swidget->xml, "cancel_clicked",
                                    G_CALLBACK (progress_operation_cancel), operation);
-    g_signal_connect (seahorse_widget_get_top (swidget), "delete_event",
+    g_signal_connect (seahorse_widget_get_toplevel (swidget), "delete_event",
                       G_CALLBACK (progress_delete_event), operation);
     
     /* Done and cleanup */
