@@ -161,7 +161,7 @@ update_uids (SeahorsePGPKey *pkey)
 		
 		/* Remove if no uid */
 		if (!guid) {
-			seahorse_object_set_parent (l->data, NULL);			
+			seahorse_object_set_parent (SEAHORSE_OBJECT (uid), NULL);			
 			pkey->uids = g_list_remove (pkey->uids, uid);
 			g_object_unref (uid);
 		} else {
@@ -245,7 +245,7 @@ changed_key (SeahorsePGPKey *pkey)
             skey->loaded = SKEY_INFO_BASIC;
         
         /* The flags */
-        obj->_flags = 0;
+        obj->_flags = SKEY_FLAG_EXPORTABLE;
     
         if (!pkey->pubkey->disabled && !pkey->pubkey->expired && 
             !pkey->pubkey->revoked && !pkey->pubkey->invalid)
