@@ -24,6 +24,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gp11.h>
+#include <gp11-hacks.h>
 
 G_BEGIN_DECLS
 
@@ -31,7 +33,8 @@ G_BEGIN_DECLS
 
 #define SEAHORSE_PKCS11_TYPE_STR "pkcs11"
 #define SEAHORSE_PKCS11_TYPE g_quark_from_string ("pkcs11")
-#define SEAHORSE_PKCS11_STOCK_ICON "seahorse-key"
+GQuark seahorse_pkcs11_id_from_attributes (GP11Attributes* attrs);
+gboolean seahorse_pkcs11_id_to_attributes (GQuark id, GP11Attributes* attrs);
 
 
 G_END_DECLS
