@@ -20,34 +20,36 @@
  */
 
 #include <config.h>
-#include <gnome.h>
 
-#include "seahorse-widget.h"
-#include "seahorse-util.h"
-#include "seahorse-gpgmex.h"
+#include <glib/gi18n.h>
+
 #include "seahorse-context.h"
-#include "seahorse-windows.h"
+#include "seahorse-gconf.h"
+#include "seahorse-key.h"
+#include "seahorse-keyserver-sync.h"
 #include "seahorse-progress.h"
 #include "seahorse-preferences.h"
-#include "seahorse-server-source.h"
-#include "seahorse-gconf.h"
+#include "seahorse-servers.h"
 #include "seahorse-transfer-operation.h"
-#include "seahorse-keyserver-sync.h"
+#include "seahorse-util.h"
+#include "seahorse-widget.h"
+#include "seahorse-windows.h"
 
 static void 
-sync_import_complete (SeahorseOperation *op, SeahorseKeySource *sksrc)
+sync_import_complete (SeahorseOperation *op, SeahorseSource *sksrc)
 {
     GError *err = NULL;
     
     if (!seahorse_operation_is_successful (op)) {
         seahorse_operation_copy_error (op, &err);
-        seahorse_util_handle_error (err, _("Couldn't publish keys to server: %s"), 
+        seahorse_util_handle_error (err, _("Couldn't publish keys to server"), 
                                     seahorse_gconf_get_string (PUBLISH_TO_KEY));
+        g_clear_error (&err);
     }    
 }
 
 static void
-sync_export_complete (SeahorseOperation *op, SeahorseKeySource *sksrc)
+sync_export_complete (SeahorseOperation *op, SeahorseSource *sksrc)
 {
     GError *err = NULL;
     gchar *keyserver;
@@ -58,6 +60,7 @@ sync_export_complete (SeahorseOperation *op, SeahorseKeySource *sksrc)
         seahorse_operation_copy_error (op, &err);
         seahorse_util_handle_error (err, _("Couldn't retrieve keys from server: %s"), 
                                     keyserver);
+        g_clear_error (&err);
         g_free (keyserver);
     }    
 }
@@ -85,19 +88,24 @@ configure_clicked (GtkButton *button, SeahorseWidget *swidget)
 static void
 update_message (SeahorseWidget *swidget)
 {
-    GtkWidget *w, *w2;
+    GtkWidget *w, *w2, *sync_button;
     gchar *t;
     
     w = glade_xml_get_widget (swidget->xml, "publish-message");
     w2 = glade_xml_get_widget (swidget->xml, "sync-message");
+    sync_button = glade_xml_get_widget (swidget->xml, "sync-button");
 
     t = seahorse_gconf_get_string (PUBLISH_TO_KEY);
     if (t && t[0]) {
         gtk_widget_show (w);
         gtk_widget_hide (w2);
+        
+        gtk_widget_set_sensitive (sync_button, TRUE);
     } else {
         gtk_widget_hide (w);
         gtk_widget_show (w2);
+        
+        gtk_widget_set_sensitive (sync_button, FALSE);
     }
     g_free (t);
 }
@@ -174,8 +182,8 @@ seahorse_keyserver_sync_show (GList *keys, GtkWindow *parent)
 void
 seahorse_keyserver_sync (GList *keys)
 {
-    SeahorseKeySource *sksrc;
-    SeahorseKeySource *lsksrc;
+    SeahorseSource *sksrc;
+    SeahorseSource *lsksrc;
     SeahorseMultiOperation *mop;
     SeahorseOperation *op;
     gchar *keyserver;
@@ -196,26 +204,25 @@ seahorse_keyserver_sync (GList *keys)
     mop = seahorse_multi_operation_new ();
 
     /* And now synchronizing keys from the servers */
-    ks = seahorse_gconf_get_string_list (KEYSERVER_KEY);
-    ks = seahorse_server_source_purge_keyservers (ks);
+    ks = seahorse_servers_get_uris ();
     
     for (l = ks; l; l = g_slist_next (l)) {
         
-        sksrc = seahorse_context_remote_key_source (SCTX_APP (), (const gchar*)(l->data));
+        sksrc = seahorse_context_remote_source (SCTX_APP (), (const gchar*)(l->data));
 
         /* This can happen if the URI scheme is not supported */
         if (sksrc == NULL)
             continue;
         
-        lsksrc = seahorse_context_find_key_source (SCTX_APP (), 
-                        seahorse_key_source_get_ktype (sksrc), SKEY_LOC_LOCAL);
+        lsksrc = seahorse_context_find_source (SCTX_APP (), 
+                        seahorse_source_get_ktype (sksrc), SEAHORSE_LOCATION_LOCAL);
         
         if (lsksrc) {
             op = seahorse_transfer_operation_new (_("Synchronizing keys"), sksrc, lsksrc, keyids);
             g_return_if_fail (op != NULL);
 
             seahorse_multi_operation_take (mop, op);
-            seahorse_operation_watch (op, G_CALLBACK (sync_export_complete), NULL, sksrc);
+            seahorse_operation_watch (op, (SeahorseDoneFunc) sync_export_complete, sksrc, NULL, NULL);
         }
     }
     
@@ -225,16 +232,16 @@ seahorse_keyserver_sync (GList *keys)
     keyserver = seahorse_gconf_get_string (PUBLISH_TO_KEY);
     if (keyserver && keyserver[0]) {
         
-        sksrc = seahorse_context_remote_key_source (SCTX_APP (), keyserver);
+        sksrc = seahorse_context_remote_source (SCTX_APP (), keyserver);
 
         /* This can happen if the URI scheme is not supported */
         if (sksrc != NULL) {
 
-            op = seahorse_context_transfer_keys (SCTX_APP (), keys, sksrc);
+            op = seahorse_context_transfer_objects (SCTX_APP (), keys, sksrc);
             g_return_if_fail (sksrc != NULL);
 
             seahorse_multi_operation_take (mop, op);
-            seahorse_operation_watch (op, G_CALLBACK (sync_import_complete), NULL, sksrc);
+            seahorse_operation_watch (op, (SeahorseDoneFunc) sync_import_complete, sksrc, NULL, NULL);
 
         }
     }
