@@ -22,7 +22,7 @@
 #ifndef __SEAHORSE_PREFERENCES_H__
 #define __SEAHORSE_PREFERENCES_H__
 
-#include "seahorse-context.h"
+#include <gtk/gtk.h>
 
 #define LISTING_SCHEMAS SEAHORSE_SCHEMAS "/listing"
 #define SHOW_VALIDITY_KEY LISTING_SCHEMAS "/show_validity"
@@ -31,8 +31,6 @@
 #define SHOW_LENGTH_KEY LISTING_SCHEMAS "/show_length"
 #define SHOW_TYPE_KEY LISTING_SCHEMAS "/show_type"
 
-#define UI_SCHEMAS SEAHORSE_SCHEMAS "/ui"
-
-void		seahorse_preferences_show		(const gchar        *tabid);
+void seahorse_preferences_show  (GtkWindow *parent, const gchar *tabid);
 
 #endif /* __SEAHORSE_PREFERENCES_H__ */
